@@ -236,7 +236,7 @@ struct thread_status {
 	int status;		/* See DM_THREAD_{REGISTERING,RUNNING,DONE} */
 
 	int events;		/* bitfield for event filter. */
-	int current_events;	/* bitfield for occured events. */
+	int current_events;	/* bitfield for occurred events. */
 	struct dm_task *wait_task;
 	int pending;		/* Set when event filter change is pending */
 	time_t next_time;
@@ -268,7 +268,7 @@ static void _free_dso_data(struct dso_data *data)
 
 static struct dso_data *_alloc_dso_data(struct message_data *data)
 {
-	struct dso_data *ret = (typeof(ret)) zalloc(sizeof(*ret));
+	struct dso_data *ret = (__typeof__(ret)) zalloc(sizeof(*ret));
 
 	if (!ret)
 		return_NULL;
@@ -427,7 +427,7 @@ static struct thread_status *_alloc_thread_status(const struct message_data *dat
 	if (!(thread->device.name = strdup(data->device_uuid)))
 		goto_out;
 
-	/* runs ioctl and may register lvm2 pluging */
+	/* runs ioctl and may register lvm2 plugin */
 	thread->processing = 1;
 	thread->status = DM_THREAD_REGISTERING;
 
@@ -520,7 +520,7 @@ static int _fetch_string(char **ptr, char **src, const int delimiter)
 			*p = delimiter;
 			*src = p;
 		}
-		(*src)++; /* Skip delmiter, next field */
+		(*src)++; /* Skip delimiter, next field */
 	} else if ((len = strlen(*src))) {
 		/* No delimiter, item ends with '\0' */
 		if (!(*ptr = strdup(*src))) {
@@ -606,11 +606,14 @@ static int _fill_device_data(struct thread_status *ts)
 	if (!dm_task_run(dmt))
 		goto fail;
 
-	free(ts->device.name);
-	if (!(ts->device.name = strdup(dm_task_get_name(dmt))))
+	if (!dm_task_get_info(dmt, &dmi))
 		goto fail;
 
-	if (!dm_task_get_info(dmt, &dmi))
+	if (!dmi.exists)
+		goto fail;
+
+	free(ts->device.name);
+	if (!(ts->device.name = strdup(dm_task_get_name(dmt))))
 		goto fail;
 
 	ts->device.major = dmi.major;
@@ -680,9 +683,15 @@ static int _get_status(struct message_data *message_data)
 		return -EINVAL;
 
 	_lock_mutex();
-	count = dm_list_size(&_thread_registry);
+	if (!(count = dm_list_size(&_thread_registry))) {
+		_unlock_mutex();
+		ret = 0;        /* no monitored devices */
+		goto out;
+	}
+
 	buffers = alloca(sizeof(char*) * count);
 	dm_list_iterate_items(thread, &_thread_registry) {
+		/* coverity[overflow_sink] - only positive 'current' is used */
 		if ((current = dm_asprintf(buffers + i, "0:%d %s %s %u %" PRIu32 ";",
 					   i, thread->dso_data->dso_name,
 					   thread->device.uuid, thread->events,
@@ -691,6 +700,7 @@ static int _get_status(struct message_data *message_data)
 			goto out;
 		}
 		++i;
+		/* coverity[overflow] - only positive 'current' is used */
 		size += current; /* count with trailing '\0' */
 	}
 	_unlock_mutex();
@@ -894,6 +904,9 @@ static int _event_wait(struct thread_status *thread)
 	}
 
 	if (dm_task_run(thread->wait_task)) {
+		/* Recheck device info whether is still exists */
+		if (!_fill_device_data(thread))
+			goto disappeared; /* device is gone... */
 		thread->current_events |= DM_EVENT_DEVICE_ERROR;
 		ret = DM_WAIT_INTR;
 		/* Update event_nr */
@@ -902,6 +915,7 @@ static int _event_wait(struct thread_status *thread)
 	} else {
 		switch (dm_task_get_errno(thread->wait_task)) {
 		case ENXIO:
+disappeared:
 			log_error("%s disappeared, detaching.",
 				  thread->device.name);
 			ret = DM_WAIT_FATAL;
@@ -958,7 +972,8 @@ static void _do_process_event(struct thread_status *thread)
 	if (!task)
 		log_error("Lost event in Thr %x.", (int)thread->thread);
 	else {
-		thread->dso_data->process_event(task, thread->current_events, &(thread->dso_private));
+		thread->dso_data->process_event(task, (enum dm_event_mask) thread->current_events,
+						&(thread->dso_private));
 		if (task != thread->wait_task)
 			dm_task_destroy(task);
 	}
