@@ -404,7 +404,7 @@ int daemon_talk(struct dm_event_fifos *fifos,
 /*
  * Check for usable client fifo file
  *
- * Returns: 2 cliant path does not exists, dmeventd should be restarted
+ * Returns: 2 client path does not exists, dmeventd should be restarted
  *          1 on success, 0 otherwise
  */
 static int _check_for_usable_fifos(char *dmeventd_path, struct dm_event_fifos *fifos)
@@ -829,7 +829,7 @@ int dm_event_get_registered_device(struct dm_event_handler *dmevh, int next)
 	}
 
 	dm_event_handler_set_dso(dmevh, reply_dso);
-	dm_event_handler_set_event_mask(dmevh, reply_mask);
+	dm_event_handler_set_event_mask(dmevh, (enum dm_event_mask) reply_mask);
 
 	free(reply_dso);
 	reply_dso = NULL;
@@ -988,7 +988,7 @@ void dm_event_log(const char *subsys, int level, const char *file,
 			fprintf(stream, "%28s:%4d %s", file, line, indent);
 		vfprintf(stream, _(format), ap);
 		fputc('\n', stream);
-		fflush(stream);
+		(void) fflush(stream);
 	}
 
 	pthread_mutex_unlock(&_log_mutex);
@@ -1007,7 +1007,7 @@ void dm_event_log(const char *subsys, int level, const char *file,
 
 static char *_skip_string(char *src, const int delimiter)
 {
-	src = srtchr(src, delimiter);
+	src = strchr(src, delimiter);
 	if (src && *(src + 1))
 		return src + 1;
 	return NULL;
