@@ -11,7 +11,7 @@ import os
 import multiprocessing
 import queue
 import itertools
-from utils import LvmDebugData
+from lvmdbusd.utils import LvmDebugData
 
 from lvmdbusd import path
 
@@ -50,6 +50,8 @@ worker_q = queue.Queue()
 # Main event loop
 loop = None
 
+G_LOOP_TMO = 0.5
+
 # Used to instruct the daemon if we should ignore SIGTERM
 ignore_sigterm = False
 
