@@ -193,6 +193,7 @@
 #define PROCESS_SKIP_SCAN	0x00200000U /* skip lvmcache_label_scan in process_each_pv */
 #define READ_FOR_ACTIVATE	0x00400000U /* command tells vg_read it plans to activate the vg */
 #define READ_WITHOUT_LOCK	0x00800000U /* caller responsible for vg lock */
+#define READ_FOR_PERSIST	0x01000000U /* command intends to perform PR operation on disks */
 
 /* vg_read returns these in error_flags */
 #define FAILED_NOT_ENABLED	0x00000001U
@@ -208,7 +209,8 @@
 #define FAILED_SYSTEMID		0x00000400U
 #define FAILED_LOCK_TYPE	0x00000800U
 #define FAILED_LOCK_MODE	0x00001000U
-#define FAILED_INTERNAL_ERROR	0x00002000U
+#define FAILED_PR_REQUIRED	0x00002000U
+#define FAILED_INTERNAL_ERROR	0x00004000U
 #define SUCCESS			0x00000000U
 
 #define VGMETADATACOPIES_ALL UINT32_MAX
@@ -814,7 +816,7 @@ struct wipe_params {
 };
 
 /* Zero out LV and/or wipe signatures */
-int wipe_lv(struct logical_volume *lv, struct wipe_params params);
+int wipe_lv(struct logical_volume *lv, struct wipe_params wp);
 
 /* Wipe any signatures and zero first sector on @lv */
 int activate_and_wipe_lv(struct logical_volume *lv, int commit);
@@ -1018,8 +1020,7 @@ struct lvcreate_params {
 	const char *lv_name; /* all */
 	const char *origin_name; /* snap */
 	const char *pool_name;   /* thin */
-
-	const char *lock_args;
+	const char *lockd_name;
 
 	uint32_t stripes; /* striped/RAID */
 	uint32_t stripe_size; /* striped/RAID */
@@ -1221,7 +1222,7 @@ int lv_add_mirrors(struct cmd_context *cmd, struct logical_volume *lv,
 		   uint32_t mirrors, uint32_t stripes, uint32_t stripe_size,
 		   uint32_t region_size, uint32_t log_count,
 		   struct dm_list *pvs, alloc_policy_t alloc, uint32_t flags);
-int lv_split_mirror_images(struct logical_volume *lv, const char *split_lv_name,
+int lv_split_mirror_images(struct logical_volume *lv, const char *split_name,
 			   uint32_t split_count, struct dm_list *removable_pvs);
 int lv_remove_mirrors(struct cmd_context *cmd, struct logical_volume *lv,
 		      uint32_t mirrors, uint32_t log_count,
@@ -1497,7 +1498,7 @@ struct dm_list *clone_pv_list(struct dm_pool *mem, struct dm_list *pvsl);
 
 int lv_add_integrity_to_raid(struct logical_volume *lv, struct integrity_settings *settings, struct dm_list *pvh,
 			     struct logical_volume *lv_imeta_0);
-int lv_remove_integrity_from_raid(struct logical_volume *lv);
+int lv_remove_integrity_from_raid(struct logical_volume *lv, char **remove_images);
 void lv_clear_integrity_recalculate_metadata(struct logical_volume *lv);
 int lv_has_integrity_recalculate_metadata(struct logical_volume *lv);
 int lv_raid_has_integrity(struct logical_volume *lv);
