@@ -20,6 +20,7 @@
 #include "lib/commands/toolcontext.h"
 #include "lib/metadata/lv_alloc.h"
 #include "lib/activate/activate.h"
+#include "lib/display/display.h"
 
 #define SNAPSHOT_MIN_CHUNKS	3       /* Minimum number of chunks in snapshot */
 
@@ -330,7 +331,7 @@ int vg_remove_snapshot(struct logical_volume *cow)
 		clear_snapshot_merge(origin);
 		/*
 		 * preload origin IFF "snapshot-merge" target is active
-		 * - IMPORTANT: avoids preload if inactivate merge is pending
+		 * - IMPORTANT: avoids preload if inactive merge is pending
 		 */
 	}
 
