@@ -393,7 +393,7 @@ teardown_devs_prefixed() {
 	for dm in $(dm_info name -S "name=~$PREFIX&&suspended=Suspended"); do
 		test "$dm" != "No devices found" || break
 		echo "## resuming: dmsetup resume \"$dm\""
-		dmsetup clear "$dm"
+		dmsetup clear "$dm" &
 		dmsetup resume "$dm" &
 	done
 
@@ -518,7 +518,9 @@ kill_sleep_kill_() {
 	if test -s "$pidfile" ; then
 		pid=$(< "$pidfile")
 		rm -f "$pidfile"
-		test "$pidfile" = "LOCAL_LVMDBUSD" && killall -9 lvmdbusd || true
+		if test "$pidfile" = "LOCAL_LVMDBUSD"; then
+			killall -9 lvmdbusd || true
+		fi
 		kill -TERM "$pid" 2>/dev/null || return 0
 		for i in {0..10} ; do
 			ps "$pid" >/dev/null || return 0
@@ -1374,6 +1376,21 @@ error_dev() {
 	common_dev_ error "$@"
 }
 
+# New kernels do not allow to create devices bigger the <8EiB
+# This gives 18014398509481983 as maximum usable sectors
+#
+# MAX_DEV_SIZE=18014398509481983
+#
+# Interestingly older kernels (3.X series) do have some strange problems
+# if there is a device of such size  (systemd-udev runs in endless loop:
+#   truncate_inode_pages_range+0x1ed/0x5e0
+#   truncate_inode_pages+0x1f/0x30
+#   kill_bdev+0x26/0x30
+#
+# As we don't really care about couple missing sectors here, just lower
+# the size to the max usable size that is not cause troubles:
+MAX_DEV_SIZE=18014398509481976
+
 #
 # Convert device to device with write errors but normal reads.
 # For this 'delay' dev is used and reroutes 'reads' back to original device
@@ -1388,7 +1405,8 @@ writeerror_dev() {
 			target_at_least dm-delay 1 1 0 || return 0
 			touch HAVE_DM_DELAY
 		fi
-		dmsetup create -u "TEST-$name" "$name" --table "0 4611686018427387904 error"
+		# error device with the size of 8EiB
+		dmsetup create -u "TEST-$name" "$name" --table "0 $MAX_DEV_SIZE error"
 		# Take major:minor of our error device
 		echo "$name" > ERR_DEV_NAME
 		dmsetup info -c  --noheadings -o major,minor "$name" > ERR_DEV
@@ -1411,7 +1429,8 @@ delayzero_dev() {
 			target_at_least dm-delay 1 1 0 || return 0
 			touch HAVE_DM_DELAY
 		fi
-		dmsetup create -u "TEST-$name" "$name" --table "0 4611686018427387904 zero"
+		# error device with the size of 8EiB
+		dmsetup create -u "TEST-$name" "$name" --table "0 $MAX_DEV_SIZE zero"
 		# Take major:minor of our error device
 		echo "$name" > ZERO_DEV_NAME
 		dmsetup info -c  --noheadings -o major,minor "$name" > ZERO_DEV
@@ -1618,6 +1637,7 @@ dmeventd/executable = "$abs_top_builddir/test/lib/dmeventd"
 activation/udev_rules = 1
 activation/udev_sync = 1
 global/fsadm_executable = "$abs_top_builddir/test/lib/fsadm"
+global/lvresize_fs_helper_executable = "$abs_top_builddir/test/lib/lvresize_fs_helper"
 global/library_dir = "$TESTDIR/lib"
 global/locking_dir = "$TESTDIR/var/lock/lvm"
 EOF
@@ -1972,6 +1992,20 @@ have_raid() {
 	esac
 }
 
+have_raid_resizable() {
+	# Check if the kernel can resize raid volume without killing leg.
+	# MD core has had a bug in handling read-ahead requests.
+	# This results in marking raid with suspended leg as failed.
+	# Bug was fixed from kernel 6.16
+	# Fixing kernel commit: 9f346f7d4ea73692b82f5102ca8698e4040469ea
+	# Patch was backported to most 6.15 releases.
+	# Note: Fixing test for this failure would likely require full raid
+	# array resync, so it's better to skip the test for affected kernels.
+	case "$(uname -r)" in
+	  6.1[34]*) return 1 ;;
+	esac
+}
+
 have_raid4 () {
 	local r=0
 
