@@ -11,9 +11,8 @@
 # Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 
-SKIP_WITH_LVMPOLLD=1
 
-. lib/inittest
+. lib/inittest --skip-with-lvmpolld
 
 aux have_raid 1 3 0 || skip
 
@@ -33,10 +32,8 @@ aux disable_dev "$dev1"
 vgreduce --force --removemissing $vg
 check raid_leg_status $vg $lv "DA"
 
-# Conversion to 2 legs does nothing on degraded 2-legged raid1 LV
-lvconvert -y -m1 $vg/$lv 2>&1 | tee out
-grep "already has 2 images" out
-# Check it remains degraded after the successful "conversion"
+# Conversion to 2 legs must fail on degraded 2-legged raid1 LV
+not lvconvert -y -m1 $vg/$lv
 check raid_leg_status $vg $lv "DA"
 
 # Repair has to succeed
