@@ -13,9 +13,8 @@
 
 test_description="ensure that 'vgreduce --removemissing' works on mirrored LV"
 
-SKIP_WITH_LVMPOLLD=1
 
-. lib/inittest
+. lib/inittest --skip-with-lvmpolld
 
 list_pvs=()
 
@@ -44,7 +43,7 @@ mimages_are_on_ ()
 	local i
 
 	echo "Check if mirror images of $lv are on PVs" "${list_pvs[@]}"
-	printf "%s\n" "${list_pvs[@]}" | sort | uniq > out1
+	printf "%s\n" "${list_pvs[@]}" | sort | uniq | tee out1
 
 	get lv_field_lv_ "$vg" lv_name -a | grep "${lv}_mimage_" | tee lvs_log
 	test -s lvs_log || return 1
@@ -53,14 +52,9 @@ mimages_are_on_ ()
 		mimages+=( "$i" )
 	done < lvs_log
 
-	for i in "${mimages[@]}"; do
-		echo "Checking $vg/$i"
-		lvs -a -o+devices "$vg/$i"
-	done
-
 	for i in "${mimages[@]}"; do
 		get lv_devices "$vg/$i"
-	done | sort | uniq > out2
+	done | sort | uniq | tee out2
 
 	diff --ignore-blank-lines out1 out2
 }
@@ -116,15 +110,23 @@ prepare_lvs_()
 
 check_and_cleanup_lvs_()
 {
-	lvs -a -o+devices $vg
+	lvs -a -o+lv_uuid,devices $vg
 	prepare_lvs_
 }
 
 recover_vg_()
 {
 	aux enable_dev "$@"
+
+	# clear outdated metadata on PVs so they can be used again
+	vgck --updatemetadata $vg
+
+	pvscan --cache
+
 	pvcreate -ff "$@"
+	# wipefs -a "$@"
 	vgextend $vg "$@"
+
 	check_and_cleanup_lvs_
 }
 
