@@ -12,9 +12,9 @@
 
 # 'Ensure that pvmove diagnoses PE-range values 2^32 and larger.'
 
-SKIP_WITH_LVMLOCKD=1
 
-. lib/inittest
+
+. lib/inittest --skip-with-lvmpolld
 
 aux prepare_vg 2
 
