@@ -1,4 +1,5 @@
-#!/bin/sh
+#!/usr/bin/env bash
+
 # Copyright (C) 2008 Red Hat, Inc. All rights reserved.
 #
 # This copyrighted material is made available to anyone wishing to use,
@@ -15,9 +16,9 @@
 #
 # 'Test pvcreate without metadata on all pvs'
 
-SKIP_WITH_LVMPOLLD=1
 
-. lib/inittest
+
+. lib/inittest --skip-with-lvmpolld
 
 aux prepare_devs 2 128
 
@@ -26,7 +27,7 @@ pvcreate "$dev1"
 pvcreate --metadatacopies 0 "$dev2"
 
 # "check lv snapshot"
-vgcreate $vg "$dev1" "$dev2"
+vgcreate $SHARED $vg "$dev1" "$dev2"
 lvcreate -aey -n $lv -l 60%FREE $vg
 lvcreate -s -n $lv2 -l 10%FREE $vg/$lv
 vgremove -f $vg
