@@ -71,7 +71,7 @@ arg(alloc_ARG, '\0', "alloc", alloc_VAL, 0, 0,
     "\\fBnormal\\fP applies common sense rules such as not placing parallel stripes\n"
     "on the same PV.\n"
     "\\fBinherit\\fP applies the VG policy to an LV.\n"
-    "\\fBcontiguous\\fP requires new PEs be placed adjacent to existing PEs.\n"
+    "\\fBcontiguous\\fP requires new PEs to be placed adjacent to existing PEs.\n"
     "\\fBcling\\fP places new PEs on the same PV as existing PEs in the same\n"
     "stripe of the LV.\n"
     "If there are sufficient PEs for an allocation, but normal does not\n"
@@ -325,7 +325,15 @@ arg(fs_ARG, '\0', "fs", string_VAL, 0, 0,
     "(deprecated.) Warning: this option does not prevent lvreduce from destroying\n"
     "file systems that are unmounted (or mounted if prompts are skipped.)\n"
     "\\fBignore\\fP: Resize the LV without checking for or handling a file system.\n"
-    "Warning: using ignore when reducing the LV size may destroy the file system.\n")
+    "Warning: using ignore when reducing the LV size may destroy the file system.\n"
+    ".sp\n"
+    "Note: If resizing an LV without a file system and the new LV size matches\n"
+    "the existing size, the command returns a \\fBnon-zero status code\\fP (failure).\n"
+    "However, if a file system resize is also requested along with the LV resize,\n"
+    "and the sizes already match, the command returns a \\fBzero status code\\fP\n"
+    "(success). This occurs because the external commands called to resize the file\n"
+    "system return success even if the new and old file system sizes are identical.\n"
+    "LVM follows the command status code behavior in this scenario.\n")
 
 arg(fsmode_ARG, '\0', "fsmode", string_VAL, 0, 0,
     "Control file system mounting behavior for fs resize.\n"
@@ -602,6 +610,35 @@ arg(settings_ARG, '\0', "settings", string_VAL, ARG_GROUPABLE, 0,
     "Combine multiple settings in quotes, or repeat the settings\n"
     "option for each.\n")
 
+arg(persist_ARG, '\0', "persist", string_VAL, 0, 0,
+    "Persistent Reservation operation.\n"
+    "start: register local key and acquire reservation.\n"
+    "stop: unregister local key, releasing reservation.\n"
+    "remove: preempt and abort another key.\n"
+    "clear: remove reservation and keys.\n"
+    "check: check if started.\n"
+    "autostart: start if the VG autostart flag is set.\n"
+    "lvmlocal.conf pr_key or host_id must be configured to use PR.\n"
+    "For local VGs, Write Exclusive (WE) is used, and for shared VGs\n"
+    "Write Exclusive, all registrants (WEAR) is used.\n"
+    "Use --setpersist to automate and/or require PR.\n")
+
+arg(setpersist_ARG, '\0', "setpersist", string_VAL, 0, 0,
+    "Set or clear flags to control persistent reservation behavior.\n"
+    "autostart: set flag, PR will be automatically started.\n"
+    "noautostart: clear autostart flag.\n"
+    "require: set flag, PR will be required to write or activate VG.\n"
+    "norequire: clear require flag.\n"
+    "y: set autostart and require flags.\n"
+    "n: clear autostart and require flags.\n"
+    "When autostart is enabled, autoactivation and auto-lockstart\n"
+    "commands will first start PR.\n"
+    "lvmlocal.conf pr_key or host_id must be configured to use PR.\n"
+    "For local VGs, enabling system_id is also recommended.\n")
+
+arg(removekey_ARG, '\0', "removekey", string_VAL, 0, 0,
+    "A persistent reservation key to remove.\n")
+
 arg(poll_ARG, '\0', "poll", bool_VAL, 0, 0,
     "When yes, start the background transformation of an LV.\n"
     "An incomplete transformation, e.g. pvmove or lvconvert interrupted\n"
